@@ -14,8 +14,8 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import absolute_import
-from calculate.core.server.loaded_methods import LoadedMethods
+ 
+from .loaded_methods import LoadedMethods
 
 import calculate.contrib
 from spyne import String, Integer, Boolean
@@ -30,7 +30,7 @@ import sys
 import pickle
 import os
 from calculate.lib.datavars import SourceReadonlyVariable
-from calculate.core.server.core_interfaces import CoreServiceInterface
+from .core_interfaces import CoreServiceInterface
 
 _ = lambda x: x
 from calculate.lib.cl_lang import setLocalTranslate
@@ -55,7 +55,7 @@ class CommonInfo(ComplexModel):
     Default = Array(String)
     CheckAll = Boolean
 
-class LazyString(object):
+class LazyString():
     pass
 
 
@@ -87,16 +87,13 @@ class DataVarsSerializer(ComplexModel):
 
     def arrayString(self, value):
         if type(value) in (list, tuple):
-            return [""] + map(lambda x: (",".join(x)
-                                         if type(x) in (list, tuple)
-                                         else x),
-                              value)
+            return [""] + [(",".join(x) if type(x) in (list, tuple) else x) for x in value]
         else:
             return value
 
     def arrayArrayString(self, value):
         if type(value) in (list, tuple):
-            return map(self.arrayString, value)
+            return [self.arrayString(x) for x in value]
         else:
             return value
 
@@ -117,7 +114,7 @@ class ChoiceValue(DataVarsSerializer):
 
     def __init__(self, dv=None, varObj=None, readOnly=False, **kwargs):
         if dv:
-            super(ChoiceValue, self).__init__()
+            super().__init__()
             if not readOnly:
                 self.values, self.comments = self.getChoice(varObj)
             elif isinstance(varObj, SourceReadonlyVariable):
@@ -137,7 +134,7 @@ class ChoiceValue(DataVarsSerializer):
                 else:
                     self.typefield = "text"
         else:
-            super(ChoiceValue, self).__init__(**kwargs)
+            super().__init__(**kwargs)
 
     def elementByType(self, typeobj):
         """Get element by variable type, given for table or not"""
@@ -166,8 +163,7 @@ class Table(DataVarsSerializer):
                  varObj=None, head=None, body=None, values=None,
                  fields=None, onClick=None, addAction=None, step=None,
                  records=None):
-        super(Table, self).__init__()
-        # print("DEBUG Table init")
+        super().__init__()
 
         if dv:
             self.head = []
@@ -214,7 +210,7 @@ class Option(DataVarsSerializer):
     help = String(default=None, min_occurs=1)
 
     def __init__(self, optlist, metaval, helpval, syntax=""):
-        super(Option, self).__init__()
+        super().__init__()
         self.help = helpval
         self.metavalue = metaval
         self.syntax = syntax
@@ -248,7 +244,7 @@ class Field(DataVarsSerializer):
         briefmode - view request for brief, inbrief - variable palced in brief,
         """
         if dv:
-            super(Field, self).__init__()
+            super().__init__()
             self.name = varObj.name
             self.type = varObj.type
             if varObj.opt:
@@ -281,7 +277,6 @@ class Field(DataVarsSerializer):
                     self.default = not varObj.wasSet
                 self.choice, self.comments = self.getChoice(varObj)
                 if self.type == "table":
-                    # print("DEBUG_table creation")
 
                     self.tablevalue = Table(dv=dv, briefmode=briefmode,
                                             varObj=varObj)
@@ -304,7 +299,7 @@ class Field(DataVarsSerializer):
                             # if self.value:
                             #    self.default = self.value
         else:
-            super(Field, self).__init__(**kwargs)
+            super().__init__(**kwargs)
 
 
 class GroupField(DataVarsSerializer):
@@ -317,7 +312,7 @@ class GroupField(DataVarsSerializer):
     def __init__(self, name="", fields=list(), prevlabel="",
                  nextlabel="", last=False, dv=None, info=None,
                  expert=False, brief=False, onlyhelp=False):
-        super(GroupField, self).__init__()
+        super().__init__()
         self.last = last
         if dv:
             self.name = info['name']
@@ -408,7 +403,7 @@ class ViewInfo(DataVarsSerializer):
     def __init__(self, datavars=None, step=None, expert=None, allsteps=False,
                  brief=None, brief_label=None, has_brief=False, groups=list(),
                  viewparams=None):
-        super(ViewInfo, self).__init__()
+        super().__init__()
         onlyhelp = False
         if viewparams:
             # for compatible specifing step by param
@@ -425,9 +420,7 @@ class ViewInfo(DataVarsSerializer):
             # interate all vars group
             if step in (0, -1, None) or allsteps:
                 briefData = datavars.getBrief()
-                # print("DEBUG viewInfo")
-                # print("var groups: %s " % bool(varGroups))
-                # print(datavars)
+
                 self.groups.append(self.stepGroup(varGroups, brief_label,
                                                   help_value=briefData.get(
                                                       "help", None),
@@ -469,9 +462,6 @@ class ViewInfo(DataVarsSerializer):
     def stepGroup(self, groupInfo, brief_label, help_value=None,
                   next_value=None, image_value=""):
         """Step group"""
-        # print("DEBUG what are you doing stepGroup")
-        # print(groupInfo)
-        # print(brief_label)
         return GroupField(fields=[
             Field(name="Steps",
                   element="table",
@@ -517,7 +507,7 @@ class ReturnedMessage(ComplexModel):
 
     def __init__(self, type=None, field=None, message=None,
                  expert=False, field_obj=None):
-        super(ReturnedMessage, self).__init__()
+        super().__init__()
         self.type = type
         self.field = field
         self.message = message
@@ -536,10 +526,10 @@ class Message(ComplexModel):
     onlyShow = String(default=None, min_occurs=1)
     default = String(default=None, min_occurs=1)
 
-    def __init__(self, type='normal', message=None, id=None,
+    def __init__(self, message_type='normal', message=None, id=None,
                  result=None, onlyShow=None, default=None):
-        super(Message, self).__init__()
-        self.type = type
+        super().__init__()
+        self.type = message_type
         self.message = message
         self.id = id
         self.result = result
@@ -555,7 +545,7 @@ class ReturnProgress(ComplexModel):
 
     def __init__(self, percent=0, short_message=None, long_message=None,
                  control=None):
-        super(ReturnProgress, self).__init__()
+        super().__init__()
         self.percent = percent
         self.short_message = short_message
         self.long_message = long_message
@@ -568,7 +558,7 @@ class Frame(ComplexModel):
 
 # get and send client messages
 class CoreWsdl(CoreServiceInterface):
-    perm_denied = [Message(type='error', message='403 Forbidden')]
+    perm_denied = [Message(message_type='error', message='403 Forbiddennnn')]
     @staticmethod
     def callAction(cls, sid, info, logicClass=None,
                    method_name=None, actionClass=None,
@@ -594,10 +584,9 @@ class CoreWsdl(CoreServiceInterface):
                 checkall = True
             elif info and hasattr(info, "CheckAll"):
                 checkall = info.CheckAll
-            errors = map(lambda x: ReturnedMessage(**x),
-                         dv.checkGroups(info,
-                                        allvars=checkall or not checkonly,
-                                        invalidators=invalidators))
+            errors = [ReturnedMessage(**x) for x 
+                in dv.checkGroups(info, allvars=checkall or not checkonly, 
+                    invalidators=invalidators)]
             # if dv.Get('cl_env_debug_set') == 'on':
             #    dv.printGroup(info)
             if errors:
@@ -608,7 +597,7 @@ class CoreWsdl(CoreServiceInterface):
             if not actionClass:
                 return []
             objs = {}
-            from calculate.core.server.func import CommonLink
+            from .func import CommonLink
 
             if isinstance(logicClass, dict):
                 for k, v in logicClass.items():
@@ -645,8 +634,6 @@ class CoreWsdl(CoreServiceInterface):
         Метод смены локализации интерфейса на лету (во время выбора
         параметров метода)
         """
-        # print("DEBUG fixInstallLocalization")
-        # print(dv)
         if "--start" not in sys.argv:
             return False
         import threading
@@ -685,7 +672,7 @@ class CoreWsdl(CoreServiceInterface):
 
         check = 0
         try:
-            fd = open(cls.sids_file, 'r')
+            fd = open(cls.sids_file, 'rb')
         except IOError:
             return 0
         while 1:
@@ -701,7 +688,7 @@ class CoreWsdl(CoreServiceInterface):
 
         if check == 0:
             return 0
-        fd = open(cls.sids_pids, 'r')
+        fd = open(cls.sids_pids, 'rb')
         while 1:
             try:
                 # read out on 1 record
@@ -766,12 +753,12 @@ class CoreWsdl(CoreServiceInterface):
     def client_send_message(cls, sid, pid, text):
         if cls.check_cert_pid(cls, sid, pid):
             cls.glob_process_dict[pid]['answer'] = text
-            return Message(type='normal', message="")
+            return Message(message_type='normal', message="")
         return CoreWsdl.perm_denied
 
 
 
-class WsdlAdapter(object):
+class WsdlAdapter():
     adapted_class = None
 
     def __init__(self, source):
