@@ -14,15 +14,15 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import print_function
-import urllib2 as u2
+
+import urllib.request as u2
 import os
 import sys
 import calculate.contrib
 from suds.transport.http import HttpTransport
 from httplib import HTTPConnection, HTTPSConnection
 import socket
-from calculate.core.datavars import DataVarsCore
+from ..datavars import DataVarsCore
 from calculate.lib.cl_lang import setLocalTranslate
 
 _ = lambda x: x
@@ -95,7 +95,7 @@ class clientHTTPSConnection(HTTPSConnection):
         for item in Subject:
             print("%s : %s" % (item[0], item[1]))
 
-        choice = raw_input(
+        choice = input(
             _("add this certificate to trusted and continue? y/[n]: "))
         if choice in ['y', 'yes', 'Y', 'YES']:
             ca_certs = self.ca_path + "cert.list"
