@@ -1606,7 +1606,7 @@ def new_key_req(key, cert_path, serv_host_name, port):
     if not req:
         sys.exit()
     crtreq = req.as_pem()
-    crtfile = open(cert_path + '/server.csr', 'w')
+    crtfile = open(cert_path + '/server.csr', 'wb')
     crtfile.write(crtreq)
     crtfile.close()
 
