@@ -187,10 +187,8 @@ def local_method(metaObject, args, unknown_args):
     import os
 
     sym_link = os.path.basename(sys.argv[0])
-    # sym_link = "cl-core"
-    #TODO uncomment
-    # if not (sym_link == 'cl-core' or  sym_link == 'cl-core_py3'):
-    if False:
+    #debug
+    if not (sym_link == 'cl-core' or sym_link == 'cl-core_py3' or sym_link == "run_debug_core.py"):
         if sym_link in LoadedMethods.conMethods.keys():
             args.method = LoadedMethods.conMethods[sym_link][0]
         else:
