@@ -14,8 +14,8 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import print_function
-from __future__ import absolute_import
+
+ 
 import sys
 import os
 import argparse
@@ -23,7 +23,7 @@ import re
 from calculate.lib.utils.common import getpass
 from calculate.lib.cl_print import color_print
 from calculate.lib.cl_lang import setLocalTranslate
-from calculate.core.server.api_types import TableAdapter
+from .api_types import TableAdapter
 from functools import reduce
 
 _ = lambda x: x
@@ -51,7 +51,7 @@ class BoolAction(argparse.Action):
     def __init__(self, option_strings, dest, nargs="?",
                  const=None, default=None, type=None, choices=None,
                  required=False, help=None, metavar=None):
-        super(BoolAction, self).__init__(
+        super().__init__(
             option_strings=option_strings, dest=dest,
             nargs=nargs, const=const, default=default,
             type=type, choices=choices, required=required,
@@ -84,7 +84,7 @@ class BoolAutoAction(BoolAction):
     available_values = ("on", "off", "yes", "no", "auto")
 
 def _print(*args):
-    print(" ".join(map(lambda x: _u8(x), args)))
+    print(" ".join((_u8(x) for x in args)))
 
 
 def get_password(text1=None, text2=None, getfromstdin=False,
@@ -200,7 +200,7 @@ def get_method_argparser(view, args, cl_core=False):
         prog=progr, add_help=False, formatter_class=RawAndDefaultsHelpFormatter)
     parser.fixBoolVariables = fix_bool_variables
 
-    for Group in ifilter(lambda x: x.fields, get_list(view.groups)):
+    for Group in (x for x in get_list(view.groups) if x.fields):
         group = parser.add_argument_group(Group.name)
         for field in get_list(Group.fields):
             if field.element == 'error':
@@ -212,13 +212,13 @@ def get_method_argparser(view, args, cl_core=False):
                 if "choice" in field.type and hasattr(field.opt, "syntax") and \
                         field.opt.syntax and "{" in field.opt.syntax:
                     lgroup = group.add_mutually_exclusive_group()
-                    help = dict(map(lambda x: (x[0].strip("'"), x[2]),
-                                    map(lambda x: x.partition(' - '),
-                                        field.help.split(',\n'))))
+                    help = dict(((x[0].strip("'"), x[2]) for x 
+                        in (y.partition(' - ') for y 
+                            in field.help.split(',\n'))))
                     choice = field.choice
                     if not type(choice) in (list, tuple):
                         choice = choice.string
-                    for val in filter(None, choice):
+                    for val in (x for x in choice if x):
                         data['action'] = 'store_const'
                         # data['nargs'] = '?'
                         data['const'] = val
@@ -279,7 +279,7 @@ def get_method_argparser(view, args, cl_core=False):
                 elif "bool" in field.type:
                     data['metavar'] = "ON/OFF"
                 try:
-                    opts = filter(None, [opt.shortopt, opt.longopt])
+                    opts = [x for x in  [opt.shortopt, opt.longopt] if x]
                     if any("-" not in x for x in opts):
                         data.pop('dest')
                         data['nargs'] = '?'
@@ -375,8 +375,8 @@ def set_table_pwd(client, param_object, field, value):
     else:
         if not getattr(param_object, field.name):
             setattr(param_object, field.name,
-                    map(lambda x: x[1:] if not x[0] else x,
-                        field.tablevalue.body))
+                    [x[1:] if not x[0] else x for x 
+                        in field.tablevalue.body])
         object_array = getattr(param_object, field.name)
 
     result = []
@@ -425,9 +425,8 @@ def display_error(error, args, groups):
                     else:
                         if field.opt.shortopt or field.opt.longopt:
                             params_text += _('Wrong option ')
-                            params_text += ' ' + ', '.join(
-                                filter(None, [field.opt.shortopt,
-                                              field.opt.longopt])) + '. %s'
+                            params_text += ' ' + ', '.join((x for x 
+                                in [field.opt.shortopt,field.opt.longopt] if x)) + '. %s'
     if list_answer:
         __print = get_terminal_print(colorPrint.defaultPrint)
         __print.foreground(TextState.Colors.WHITE)(
@@ -448,7 +447,7 @@ def display_error(error, args, groups):
                     __print.bold.foreground(TextState.Colors.WHITE)("*")
                 __print("\n")
         if not comments:
-            for v in filter(None, values):
+            for v in (x for x in values if x):
                 __print("  ")
                 __print.bold("[" + v + "]")
                 if value == v:
@@ -456,9 +455,9 @@ def display_error(error, args, groups):
                     __print.bold.foreground(TextState.Colors.WHITE)("*")
                 __print("\n")
     elif error.type != "commonerror":
-        colorPrint.printERROR(params_text % error.message)
+        colorPrint.printERROR(params_text % error)
     else:
-        colorPrint.printWARNING(error.message)
+        colorPrint.printWARNING(error)
 
 
 def check_result_msg(method_result, view, input_error_dict=None, args=None):
@@ -470,7 +469,7 @@ def check_result_msg(method_result, view, input_error_dict=None, args=None):
 
     for error in method_result:
         if error.type == 'pwderror':
-            password_errors[error.field] = error.message
+            password_errors[error.field] = error
             continue
 
         display_error(error, args, view.groups)
@@ -620,30 +619,30 @@ def collect_table(field, val_list, client, wait_thread=None,
         return None
     # if specified syntax for table row
     if hasattr(field.opt, "syntax") and field.opt.syntax:
+        #TODO this could be buggy in py3, check
         reArgs = re.compile(field.opt.syntax)
         # check for correct sentense
-        for wrong in ifilterfalse(reArgs.search, val_list):
+        for wrong in filterfalse(reArgs.search, val_list):
             # raise Error on wrong
             raise ValueError(_("Wrong %s value syntax") %
                              (field.opt.shortopt or field.opt.longopt)
                              + " " + wrong)
         # create groupdict from all vals
-        argDict = map(lambda x: x.groupdict(), map(reArgs.search, val_list))
+        argDict = [x.groupdict() for x in map(reArgs.search, val_list)] 
         # convert groupdicts to val_table
         val_table = list(convertArgDictToList(argDict))
     # standard syntax
     else:
         reduced_list = list(val_list)
-        val_table = map(lambda x: x.split(':'), reduced_list)
+        val_table = [x.split(':') for x in reduced_list]
 
     if type(field.tablevalue.values) in [list, tuple]:
         choiceValue = field.tablevalue.values
     else:
         choiceValue = field.tablevalue.values.ChoiceValue
-    choiceValue = filter(lambda x: x.typefield != 'readonly', choiceValue)
+    choiceValue = [x for x in choiceValue if x.typefield != 'readonly']
     lenChoiceValue = len(choiceValue)
-    for wrong in ifilter(lambda x: len(x) > lenChoiceValue,
-                         val_table):
+    for wrong in (x for x in val_table if len(x) > lenChoiceValue):
         if type(wrong) in (list, tuple):
             wrong = ":".join(wrong)
         raise ValueError(_("Wrong %s value syntax") %
@@ -687,8 +686,8 @@ def collect_table(field, val_list, client, wait_thread=None,
                 if received_password is None:
                     raise KeyboardInterrupt
         temp_row = []
-        for val, choice_value in izip_longest(
-                line, filter(lambda x: x.typefield != 'readonly', choiceValue),
+        for val, choice_value in zip_longest(
+                line, (x for x in choiceValue if x.typefield != 'readonly'),
                 fillvalue=''):
             typefield = choice_value.typefield
             # if readonly, except first column
@@ -766,10 +765,8 @@ def getErrorOnParam(args, field):
     Get errors for param
     """
     params_text = ""
-    if any("-" in x
-           for x in filter(None, (field.opt.longopt, field.opt.shortopt))):
-        param_name = ', '.join(filter(None,
-                                      [field.opt.shortopt, field.opt.longopt]))
+    if any("-" in x for x in (y for y in (field.opt.longopt, field.opt.shortopt) if y)):
+        param_name = ', '.join((x for x in [field.opt.shortopt, field.opt.longopt] if x))
     else:
         param_name = field.opt.metavalue
     if getattr(args, field.name) is None and "need" not in field.type:
